<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Pendaftaran Berhasil</title>
    <link href="https://cdn.jsdelivr.net/npm/tailwindcss@2.2.19/dist/tailwind.min.css" rel="stylesheet">
</head>
<body class="bg-gray-100 flex items-center justify-center min-h-screen">
    <div class="bg-white p-8 rounded-lg shadow-md w-full max-w-md text-center">
        <h2 class="text-2xl font-bold mb-4 text-green-600">Pendaftaran Berhasil!</h2>
        <p class="text-gray-700 mb-6">
            Akun Anda telah berhasil didaftarkan. Mohon tunggu persetujuan dari Admin kami.
            Anda akan menerima notifikasi setelah akun Anda disetujui.
        </p>
        <a href="<?php echo e(route('filament.admin.auth.login')); ?>" class="bg-blue-500 hover:bg-blue-700 text-white font-bold py-2 px-4 rounded focus:outline-none focus:shadow-outline">
            Kembali ke Halaman Login
        </a>
    </div>
</body>
</html><?php /**PATH /home/sipf6197/laravel/resources/views/auth/register-success.blade.php ENDPATH**/ ?>